
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2019-01-16T13:59:08-0600",
 "dirty": false,
 "error": null,
 "full-revisionid": "c3b5d3af477afe49ff0e56422b7bee631ea65d2a",
 "version": "3.17.7"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
